==> jc-1.4.0.tar.gz: java/net/URLEncoder.h <==
// public class java.net.URLEncoder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4b2eca12e89f0fc java_net_URLEncoder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_URLEncoder_H_
#define _JC_java_net_URLEncoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_URLEncoder$sub_refs	_jc_java_net_URLEncoder$sub_refs;
typedef struct _jc_java_net_URLEncoder$sub_nonrefs	_jc_java_net_URLEncoder$sub_nonrefs;
typedef struct _jc_java_net_URLEncoder$refs	_jc_java_net_URLEncoder$refs;
typedef struct _jc_java_net_URLEncoder$nonrefs	_jc_java_net_URLEncoder$nonrefs;
typedef struct _jc_java_net_URLEncoder$object	_jc_java_net_URLEncoder$object;

typedef struct _jc_java_net_URLEncoder$fields_struct	_jc_java_net_URLEncoder$fields_struct;
typedef const struct _jc_java_net_URLEncoder$vmethods	_jc_java_net_URLEncoder$vmethods;
typedef const struct _jc_java_net_URLEncoder$vtable	_jc_java_net_URLEncoder$vtable;
typedef const struct _jc_java_net_URLEncoder$vtype	_jc_java_net_URLEncoder$vtype;

// Class fields structure
struct _jc_java_net_URLEncoder$fields_struct {
	struct _jc_java_lang_String$object	*hex;
};
extern _jc_java_net_URLEncoder$fields_struct _jc_java_net_URLEncoder$class_fields;

// Constructors
extern void _jc_java_net_URLEncoder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_URLEncoder$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_net_URLEncoder$method$encode$771f3a53468a38d5(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_URLEncoder$method$encode$8ef4a9098950e000(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_java_net_URLEncoder$method$isSafe$f6eb825274705bb1(_jc_env *, jchar);

// Virtual methods structure
struct _jc_java_net_URLEncoder$vmethods {
};

// Vtable
struct _jc_java_net_URLEncoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLEncoder$vmethods	java_net_URLEncoder;
};

// Vtype
struct _jc_java_net_URLEncoder$vtype {
	_jc_type			type;
	_jc_java_net_URLEncoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLEncoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_URLEncoder$refs {
    _jc_java_net_URLEncoder$sub_refs	java_net_URLEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLEncoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLEncoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLEncoder$sub_nonrefs	java_net_URLEncoder;
};

// Object instance structure
struct _jc_java_net_URLEncoder$object {
	_jc_java_net_URLEncoder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLEncoder$vtype	*vtype;
	_jc_java_net_URLEncoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLEncoder$vtype _jc_java_net_URLEncoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLEncoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLEncoder$class_object;

#endif	/* _JC_java_net_URLEncoder_H_ */

==> jc-1.4.6.tar.gz: java/net/URLEncoder.h <==
// public class java.net.URLEncoder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4b2eca12e89f0fc java_net_URLEncoder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_URLEncoder_H_
#define _JC_java_net_URLEncoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_URLEncoder$sub_refs	_jc_java_net_URLEncoder$sub_refs;
typedef struct _jc_java_net_URLEncoder$sub_nonrefs	_jc_java_net_URLEncoder$sub_nonrefs;
typedef struct _jc_java_net_URLEncoder$refs	_jc_java_net_URLEncoder$refs;
typedef struct _jc_java_net_URLEncoder$nonrefs	_jc_java_net_URLEncoder$nonrefs;
typedef struct _jc_java_net_URLEncoder$object	_jc_java_net_URLEncoder$object;

typedef struct _jc_java_net_URLEncoder$fields_struct	_jc_java_net_URLEncoder$fields_struct;
typedef const struct _jc_java_net_URLEncoder$vmethods	_jc_java_net_URLEncoder$vmethods;
typedef const struct _jc_java_net_URLEncoder$vtable	_jc_java_net_URLEncoder$vtable;
typedef const struct _jc_java_net_URLEncoder$vtype	_jc_java_net_URLEncoder$vtype;

// Class fields structure
struct _jc_java_net_URLEncoder$fields_struct {
	struct _jc_java_lang_String$object	*hex;
};
extern _jc_java_net_URLEncoder$fields_struct _jc_java_net_URLEncoder$class_fields;

// Constructors
extern void _jc_java_net_URLEncoder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_URLEncoder$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_net_URLEncoder$method$encode$771f3a53468a38d5(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_URLEncoder$method$encode$8ef4a9098950e000(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_net_URLEncoder$method$isSafe$f6eb825274705bb1(_jc_env *, jchar) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_URLEncoder$vmethods {
};

// Vtable
struct _jc_java_net_URLEncoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLEncoder$vmethods	java_net_URLEncoder;
};

// Vtype
struct _jc_java_net_URLEncoder$vtype {
	_jc_type			type;
	_jc_java_net_URLEncoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLEncoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_URLEncoder$refs {
    _jc_java_net_URLEncoder$sub_refs	java_net_URLEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLEncoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLEncoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLEncoder$sub_nonrefs	java_net_URLEncoder;
};

// Object instance structure
struct _jc_java_net_URLEncoder$object {
	_jc_java_net_URLEncoder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLEncoder$vtype	*vtype;
	_jc_java_net_URLEncoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLEncoder$vtype _jc_java_net_URLEncoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLEncoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLEncoder$class_object;

#endif	/* _JC_java_net_URLEncoder_H_ */
